@@ -1,10 +1,9 @@
 package Siebel::COM;
 
-use 5.010;
-use Moose::Role;
-use Devel::AssertOS qw(MSWin32);
-
-our $VERSION = 0.2;
+use warnings;
+use strict;
+use Moose::Role 2.1604;
+our $VERSION = '0.3'; # VERSION
 
 has '_ole' => (
     is       => 'ro',
@@ -105,7 +104,7 @@ L<Siebel::COM::App::DataControl>
 
 =item *
 
-Project website: L<https://code.google.com/p/siebel-com/>
+Project website: L<https://github.com/glasswalk3r/siebel-com>
 
 =back
 
@@ -115,7 +114,7 @@ Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
 
 This file is part of Siebel COM project.
 
