@@ -1,15 +1,17 @@
 package Siebel::COM::App;
 
-use 5.010;
-use Win32::OLE;
-use Moose;
-use MooseX::FollowPBP;
+use strict;
+use Win32::OLE 0.17;
+use Moose 2.1604;
+use MooseX::FollowPBP 0.05;
 use Siebel::COM::Business::Object;
 use Siebel::COM::Business::Object::DataServer;
-use namespace::autoclean;
+use namespace::autoclean 0.25;
 
 with 'Siebel::COM';
 
+our $VERSION = '0.3'; # VERSION
+
 has 'user'      => ( is => 'ro', isa => 'Str', required => 1 );
 has 'password'  => ( is => 'ro', isa => 'Str', required => 1 );
 has 'ole_class' => ( is => 'ro', isa => 'Str', required => 1 );
@@ -154,7 +156,7 @@ Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 This file is part of Siebel COM project.
 
