@@ -1,10 +1,11 @@
 package Siebel::COM::App::DataControl;
 
-use 5.010;
-use Moose;
-use namespace::autoclean;
+use strict;
+use Moose 2.1604;
+use namespace::autoclean 0.25;
 
 extends 'Siebel::COM::App';
+our $VERSION = '0.3'; # VERSION
 
 has host       => ( is => 'rw', isa => 'Str', required => 1 );
 has enterprise => ( is => 'rw', isa => 'Str', required => 1 );
@@ -117,7 +118,7 @@ sub DEMOLISH {
 }
 
 __PACKAGE__->meta->make_immutable;
-1;
+
 __END__
 
 =head1 NAME
@@ -332,7 +333,7 @@ Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 This file is part of Siebel COM project.
 
