@@ -1,13 +1,12 @@
 package Siebel::COM::App::DataServer;
 
-use 5.010;
 use strict;
-use warnings;
-use Moose;
-use namespace::autoclean;
+use Moose 2.1604;
+use namespace::autoclean 0.25;
 
 extends 'Siebel::COM::App';
 with 'Siebel::COM::Exception::DataServer';
+our $VERSION = '0.3'; # VERSION
 
 has cfg         => ( is => 'rw', isa => 'Str', required => 1 );
 has data_source => ( is => 'rw', isa => 'Str', required => 1 );
@@ -88,7 +87,6 @@ sub get_bus_object {
 }
 
 __PACKAGE__->meta->make_immutable;
-1;
 __END__
 
 =head1 NAME
@@ -224,7 +222,7 @@ Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 This file is part of Siebel COM project.
 
