@@ -1,11 +1,13 @@
 package Siebel::COM::Business::Component::DataServer;
 
-use 5.010;
-use Moose;
+use strict;
+use Moose 2.1604;
+use namespace::autoclean 0.25;
 use Siebel::COM::Constants;
 
 extends 'Siebel::COM::Business::Component';
 with 'Siebel::COM::Exception::DataServer';
+our $VERSION = '0.3'; # VERSION
 
 around 'activate_field' => sub {
 
@@ -152,7 +154,6 @@ around 'set_view_mode' => sub {
 
 __PACKAGE__->meta->make_immutable;
 
-1;
 __END__
 
 =head1 NAME
@@ -207,7 +208,7 @@ Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2013 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 This file is part of Siebel COM project.
 
