@@ -1,11 +1,13 @@
 package Siebel::COM::Business::Object::DataServer;
 
-use 5.010;
-use Moose;
+use strict;
+use Moose 2.1604;
+use namespace::autoclean 0.25;
 use Siebel::COM::Business::Component::DataServer;
 
 extends 'Siebel::COM::Business::Object';
 with 'Siebel::COM::Exception::DataServer';
+our $VERSION = '0.3'; # VERSION
 
  # :TODO      :06/02/2013 12:31:48:: maybe a new parameter named classname would do in the parent class? with that, a proper around could be used
 sub get_bus_comp {
@@ -26,7 +28,8 @@ sub get_bus_comp {
 
 }
 
-1;
+__PACKAGE__->meta->make_immutable;
+
 __END__
 
 =head1 NAME
@@ -75,7 +78,7 @@ Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2013 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 This file is part of Siebel COM project.
 
