@@ -1,9 +1,9 @@
 package Siebel::COM::Constants;
 
-use 5.010;
 use strict;
 use warnings;
 use Exporter 'import';
+our $VERSION = '0.3'; # VERSION
 
 our @EXPORT =
   qw(FORWARD_ONLY FORWARD_BACKWARD SALES_REP_VIEW MANAGER_VIEW PERSONAL_VIEW ALL_VIEW ORG_VIEW CATALOG_VIEW SUB_ORG_VIEW GROUP_VIEW);
@@ -103,7 +103,7 @@ Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 This file is part of Siebel COM project.
 
