@@ -1,9 +1,10 @@
 package Siebel::COM::Exception::DataServer;
 
-use 5.010;
-use feature 'say';
+use warnings;
+use strict;
 use Win32::OLE::Variant;
-use Moose::Role;
+use Moose::Role 2.1604;
+our $VERSION = '0.3'; # VERSION
 
 has 'return_code' => (
     is      => 'ro',
